calendarui/views/inc/calendayviewwidget.h
changeset 49 5de72ea7a065
parent 26 a949c2543c15
--- a/calendarui/views/inc/calendayviewwidget.h	Fri Jun 11 13:37:54 2010 +0300
+++ b/calendarui/views/inc/calendayviewwidget.h	Wed Jun 23 18:11:28 2010 +0300
@@ -21,6 +21,7 @@
 // System includes
 #include <QGraphicsLinearLayout>
 #include <QDateTime>
+#include <QPointer>
 #include <hbwidget.h>
 
 // User includes
@@ -31,6 +32,7 @@
 class HbAbstractViewItem;
 class HbGroupBox;
 class HbListView;
+class QPluginLoader;
 class HbLabel;
 class HbAction;
 class HbDateTimePicker;
@@ -309,11 +311,11 @@
 	int mSelectedIndex;
 	
 	/**
 	 * @var NotesEditor
 	 * @brief Pointer to the notes editor
 	 */
-	NotesEditor *mNotesEditor;
-	
+	QPointer<QPluginLoader> mNotesEditorPluginLoader;
+
 	/**
 	 * @var mDatePicker
 	 * @brief The date picker component
@@ -344,7 +346,13 @@
 	 * @brief Set flag true if contextmenu is opened
 	 */
 	bool mLongTapEventFlag;
-	
+
+	/**
+	 * @var mNotesPluginLoaded
+	 * @brief Holds notes editor plugin load info.
+	 */
+	bool mNotesPluginLoaded;
+
 };
 
 #endif //CALENDAYVIEWWIDGET_H
@@ -309,11 +311,11 @@
 	
 	/**
-	 * @var NotesEditor
-	 * @brief Pointer to the notes editor
+	 * @var NotesEditorPluginLoader
+	 * @brief Pointer to the notes editor plugin loader
 	 */